@@ -13,6 +13,7 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+from __future__ import absolute_import
 from contextlib import contextmanager
 
 import sys
@@ -22,8 +23,8 @@ from calculate.lib.cl_xml import xpath
 import time
 import fcntl
 
-from utils.common import _error
-from cl_template import FormatFactory, TemplatesError
+from .utils.common import _error
+from .cl_template import FormatFactory, TemplatesError
 
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -40,7 +41,7 @@ class iniParser(_error):
         # название ini файла
         self.iniFile = iniFile or ""
         # права создаваемого ini-файла
-        self.mode = 0640
+        self.mode = 0o640
         # Cоответствует ли формат файла нужному
         self.checkIni = None
         self.FD = None
