@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from random import choice
 import os
 import re
@@ -23,7 +24,7 @@ from calculate.lib.utils.dracut import Dracut
 from calculate.lib.utils.system import SystemPath
 import sys
 import getpass
-from types import StringType
+# from types import StringType
 import string
 import glob
 import pwd
@@ -100,13 +101,13 @@ def getpathenv():
     return ":".join(envPath)
 
 
-from files import process, listDirectory
+from .files import process, listDirectory
 
 def cmpVersion(v1, v2):
     """Compare versions specified by tuple or string"""
-    if isinstance(v1, StringType):
+    if isinstance(v1, str):
         v1 = getTupleVersion(v1)
-    if isinstance(v2, StringType):
+    if isinstance(v2, str):
         v2 = getTupleVersion(v2)
     return cmp((v1[0] + [0, ] * (len(v2[0]) - len(v1[0])), v1[1]),
                (v2[0] + [0, ] * (len(v1[0]) - len(v2[0])), v2[1]))
